package com.example.epl498_labs.ui.firebase;

import android.app.DatePickerDialog;
import android.os.Bundle;

import androidx.fragment.app.Fragment;
import androidx.navigation.fragment.NavHostFragment;

import android.os.Handler;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.RadioGroup;
import android.widget.Toast;

import com.example.epl498_labs.R;
import com.example.epl498_labs.databinding.FragmentFirebaseBinding;
import com.google.firebase.firestore.CollectionReference;
import com.google.firebase.firestore.FirebaseFirestore;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

/**
 * This class is responsible for demonstrating firebase features
 */
public class FirebaseFragment extends Fragment {

    private FragmentFirebaseBinding binding;
    private EditText editTextName, editTextSurname, editTextDescription, editTextBirthdate;
    private RadioGroup radioGroupFindUs;
    private Button buttonSubmit;

    private FirebaseFirestore db;
    private CollectionReference usersCollection;
    private DatePickerDialog datePickerDialog;
    private SimpleDateFormat dateFormat;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        db = FirebaseFirestore.getInstance();
        usersCollection = db.collection("users");
        dateFormat = new SimpleDateFormat("dd-MM-yyyy");
    }

    @Override
    public View onCreateView(
            LayoutInflater inflater, ViewGroup container,
            Bundle savedInstanceState
    ) {
        // Inflate the binding for this fragment
        binding = FragmentFirebaseBinding.inflate(inflater, container, false);

        // Initialize UI elements
        editTextName = binding.editTextName;
        editTextSurname = binding.editTextSurname;
        editTextDescription = binding.editTextDescription;
        editTextBirthdate = binding.editTextBirthdate;
        radioGroupFindUs = binding.radioGroupFindUs;
        buttonSubmit = binding.buttonSubmit;

        // Initialize the DatePickerDialog
        datePickerDialog = new DatePickerDialog(requireContext(), (view, year, month, dayOfMonth) -> {
            Calendar calendar = Calendar.getInstance();
            calendar.set(year, month, dayOfMonth);

            // Format the date
            String formattedDate = dateFormat.format(calendar.getTime());

            // Display the formatted date in the EditText
            editTextBirthdate.setText(formattedDate);
        }, Calendar.getInstance().get(Calendar.YEAR), Calendar.getInstance().get(Calendar.MONTH), Calendar.getInstance().get(Calendar.DAY_OF_MONTH));

        // Show date picker dialog when the birthdate EditText is clicked
        editTextBirthdate.setOnClickListener(v -> datePickerDialog.show());

        // Define a click listener for the "Save" button
        buttonSubmit.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                // Get user input
                String name = editTextName.getText().toString();
                String surname = editTextSurname.getText().toString();
                String description = editTextDescription.getText().toString();
                Date birthdate = null;
                try {
                    birthdate = dateFormat.parse(editTextBirthdate.getText().toString());
                } catch (ParseException e) {
                    throw new RuntimeException(e);
                }

                // Get the selected radio button
                RadioButton radioButton = binding.getRoot().findViewById(radioGroupFindUs.getCheckedRadioButtonId());
                String howDidYouFindUs = (String) radioButton.getText();

                // Create a User object
                User user = new User(name, surname, birthdate, description, howDidYouFindUs);

                // Add user data to Firestore
                usersCollection.add(user)
                        .addOnSuccessListener(documentReference -> {
                            // Show a success message
                            Toast.makeText(requireContext(), "Info Saved Successfully", Toast.LENGTH_SHORT).show();

                            // Post a delayed action to navigate after 3 seconds
                            new Handler().postDelayed(new Runnable() {
                                @Override
                                public void run() {
                                    // Get the ID of the newly created user in Firestore
                                    String documentReferenceId = documentReference.getId();

                                    // Create a bundle to send the resource ID to the new fragment
                                    Bundle bundle = new Bundle();
                                    bundle.putString("documentReferenceId", documentReferenceId);

                                    // Navigate to the UserViewInfoFragment with the bundle
                                    NavHostFragment.findNavController(FirebaseFragment.this)
                                            .navigate(R.id.action_FirebaseFragment_to_UserViewInfoFragment, bundle);
                                }
                            }, 3000); // 3000 milliseconds (3 seconds)
                        })
                        .addOnFailureListener(e -> {
                            // Show a failure message
                            Toast.makeText(requireContext(), "Failure: info was not saved...", Toast.LENGTH_LONG).show();
                        });
            }
        });

        return binding.getRoot();
    }
}
