package com.example.epl498_labs.ui.firebase;

import android.os.Bundle;

import androidx.annotation.NonNull;
import androidx.fragment.app.Fragment;
import androidx.navigation.fragment.NavHostFragment;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.RadioGroup;
import android.widget.TextView;
import android.widget.Toast;

import com.example.epl498_labs.R;
import com.example.epl498_labs.databinding.FragmentUserViewInfoBinding;
import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.firestore.DocumentReference;
import com.google.firebase.firestore.DocumentSnapshot;
import com.google.firebase.firestore.FirebaseFirestore;
import com.google.firebase.firestore.Source;

import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * This class is responsible for demonstrating how to read firebase data
 */
public class UserViewInfoFragment extends Fragment {

    String documentReferenceId;
    private FragmentUserViewInfoBinding binding;
    private TextView textName, textSurname, textDescription, textBirthdate;
    private RadioGroup radioGroupFindUs;
    private FirebaseFirestore db;
    private SimpleDateFormat dateFormat;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        // Retrieve the bundle from the arguments to get the document reference ID
        Bundle args = getArguments();
        if (args != null) {
            documentReferenceId = args.getString("documentReferenceId");
        }

        // Initialize Firebase Firestore and date format
        db = FirebaseFirestore.getInstance();
        dateFormat = new SimpleDateFormat("dd-MM-yyyy");
    }

    @Override
    public View onCreateView(
            LayoutInflater inflater, ViewGroup container,
            Bundle savedInstanceState
    ) {
        // Inflate the binding for this fragment
        binding = FragmentUserViewInfoBinding.inflate(inflater, container, false);

        // Initialize UI elements
        textName = binding.textName;
        textSurname = binding.textSurname;
        textDescription = binding.textDescription;
        textBirthdate = binding.textBirthdate;
        radioGroupFindUs = binding.radioGroupFindUs;

        // Get a reference to the Firestore document based on the documentReferenceId
        DocumentReference docRef = db.collection("users").document(documentReferenceId);

        // Source can be CACHE, SERVER, or DEFAULT.
        Source source = Source.DEFAULT;

        // Retrieve the document data from Firestore
        docRef.get(source).addOnCompleteListener(new OnCompleteListener<DocumentSnapshot>() {
            @Override
            public void onComplete(@NonNull Task<DocumentSnapshot> task) {
                if (task.isSuccessful()) {
                    DocumentSnapshot document = task.getResult();
                    if (document.exists()) {
                        // Set the retrieved user data in the UI
                        setUserInfo(document);
                    } else {
                        Toast.makeText(requireContext(), "Document does not exist", Toast.LENGTH_LONG).show();
                    }
                } else {
                    Toast.makeText(requireContext(), "Failure: could not retrieve data...", Toast.LENGTH_LONG).show();
                }
            }
        });

        // Set up a click listener for a button that navigates to the user edit info fragment
        binding.buttonEdit.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Bundle bundle = new Bundle();
                // Send the document reference ID to the new fragment
                bundle.putString("documentReferenceId", documentReferenceId);
                NavHostFragment.findNavController(UserViewInfoFragment.this)
                        .navigate(R.id.action_UserViewInfoFragment_to_UserEditInfoFragment, bundle);
            }
        });

        return binding.getRoot();
    }

    // Helper method to set user information in the UI
    private void setUserInfo(DocumentSnapshot document) {
        // Get data from the document
        String name = document.getString("name");
        String surname = document.getString("surname");
        String description = document.getString("description");
        Date birthdate = document.getDate("birthdate");
        String howDidYouFindUs = document.getString("howDidYouFindUs");

        if (howDidYouFindUs != null) {
            // Check the appropriate radio button based on how the user found the app
            switch (howDidYouFindUs) {
                case "Online":
                    radioGroupFindUs.check(binding.radioOnline.getId());
                    break;
                case "A friend":
                    radioGroupFindUs.check(binding.radioFriend.getId());
                    break;
                case "Other":
                    radioGroupFindUs.check(binding.radioOther.getId());
                    break;
            }
        }

        // Set the retrieved data to the respective TextViews
        textName.setText(name);
        textSurname.setText(surname);
        textDescription.setText(description);

        if (birthdate != null) {
            textBirthdate.setText(dateFormat.format(birthdate));
        }
    }
}
